@@ -42,6 +42,7 @@ async def send_embed_control(ctx, embed_control: "EmbedControl"):
     emoji_to_add = [emoji_cache.get_by_name(e) for e in embed_control.emoji_buttons]
     add = [message.add_reaction(e) for e in emoji_to_add]
     await asyncio.gather(*add)
+    return message
 
 
 async def update_embed_control(message: Message, next_embed_control: Optional["EmbedControl"], emoji_diff: Dict):
@@ -70,6 +71,7 @@ def diff_emojis(message: Message, next_embed_control: Optional["EmbedControl"]):
 
 def diff_emojis_raw(current_emojis: List[Reaction], next_emojis: List[Reaction]):
     return {
-        'add': list(set(e for e in next_emojis if e and e not in current_emojis)),
+        'add': sorted(set(
+            e for e in next_emojis if e and e not in current_emojis), key=lambda x: next_emojis.index(x)),
         'remove': list(set(e for e in current_emojis if e and e not in next_emojis)),
     }
